@@ -1,8 +1,6 @@
 /**
  * @file agShell.c
  *
- *  Time-stamp:        "2012-03-04 19:08:09 bkorb"
- *
  *  Manage a server shell process
  *
  *  This file is part of AutoGen.
@@ -59,7 +57,8 @@ ag_scm_chdir(SCM dir)
  * what:  invoke a shell script
  * general_use:
  *
- * exparg: command, shell command - the result value is the stdout output.
+ * exparg: command, shell command - the result is from stdout, , list
+ * This may be a list of strings and they will all be concatenated.
  *
  * doc:
  *  Generate a string by writing the value to a server shell and reading the
@@ -82,8 +81,16 @@ ag_scm_shell(SCM cmd)
 #ifndef SHELL_ENABLED
     return cmd;
 #else
-    if (! AG_SCM_STRING_P(cmd))
-        return SCM_UNDEFINED;
+    if (! AG_SCM_STRING_P(cmd)) {
+        static SCM joiner = SCM_UNDEFINED;
+        if (joiner == SCM_UNDEFINED)
+            joiner = scm_gc_protect_object(AG_SCM_STR02SCM(""));
+
+        cmd = ag_scm_join(joiner, cmd);
+        if (! AG_SCM_STRING_P(cmd))
+            return SCM_UNDEFINED;
+    }
+
     {
         char* pz = shell_cmd(ag_scm2zchars(cmd, "command"));
         cmd   = AG_SCM_STR02SCM(pz);
@@ -194,6 +201,8 @@ close_server_shell(void)
 #endif
     (void)kill(serv_id, SIGKILL);
     serv_id = NULLPROCESS;
+    if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
+        fprintf(trace_fp, "close_server_shell in %u state\n", processing_state);
 
     /*
      *  This guard should not be necessary.  However, sometimes someone
@@ -639,6 +648,9 @@ shell_cmd(char const * cmd)
      *  THEN try to start it.
      */
     if (serv_id == NULLPROCESS) {
+        static int was_started = 0;
+        if (was_started++ > 0)
+            fprintf(stderr, "SERVER RESTART:  serv_id is NULLPROCESS\n");
         putenv((char *)SHELL_SET_PS4_FMT);
         serv_id = server_fp_open(&serv_pair, server_args);
         if (serv_id > 0)
