@@ -2,8 +2,6 @@
 /**
  * @file defLex.c
  *
- *  Time-stamp:        "2012-03-31 13:00:08 bkorb"
- *
  *  This module scans the template variable declarations and passes
  *  tokens back to the parser.
  *
@@ -121,7 +119,7 @@ lex_escaped_char(void)
 {
     static int const semi_colon = ';';
 
-    char* pz = strchr(cctx->scx_scan, semi_colon);
+    char * pz = strchr(cctx->scx_scan, semi_colon);
 
     for (;;) {
         if (pz == NULL) {
@@ -130,7 +128,7 @@ lex_escaped_char(void)
         }
         if (IS_WHITESPACE_CHAR(pz[1])) {
             *pz = NUL;
-            pz[1] = semi_colon;
+            pz[1] = (char)semi_colon;
             break;
         }
         pz = strchr(pz+1, semi_colon);
@@ -255,7 +253,7 @@ scanAgain:
 
     case '#':
     {
-        extern char * processDirective(char*);
+        extern char * processDirective(char *);
         char * pz = processDirective(cctx->scx_scan+1);
         /*
          *  Ensure that the compiler doesn't try to save a copy of
@@ -330,13 +328,13 @@ scanAgain:
 
     return token_code;
 
-NUL_error:
+ NUL_error:
 
     AG_ABEND(aprf(DEF_ERR_FMT, ag_pname, YYLEX_UNENDING_QUOTE,
                   cctx->scx_fname, cctx->scx_line));
     return DP_EV_INVALID;
 
-lex_done:
+ lex_done:
     /*
      *  First time through, return the DP_EV_END token.
      *  Second time through, we really finish.
@@ -348,7 +346,7 @@ lex_done:
         return DP_EV_INVALID;
     }
 
-    cctx->scx_scan = (char*)zNil;
+    cctx->scx_scan = (char *)zNil;
     return DP_EV_END;
 #undef SET_LIT_TKN
 }
@@ -385,9 +383,9 @@ static void
 loadScheme(void)
 {
     char*    pzText    = cctx->scx_scan;
-    char*    pzEnd     = (char*)skip_scheme(pzText, pzText + strlen(pzText));
+    char*    pzEnd     = (char *)skip_scheme(pzText, pzText + strlen(pzText));
     char     endCh     = *pzEnd;
-    int      schemeLen = (pzEnd - pzText);
+    int      schemeLen = (int)(pzEnd - pzText);
     int      next_ln;
     SCM      res;
 
@@ -409,7 +407,7 @@ loadScheme(void)
     *pzEnd = endCh;
 
     cctx->scx_scan = pzEnd;
-    pzEnd = (char*)scm2display(res); /* ignore const-ness */
+    pzEnd = (char *)scm2display(res); /* ignore const-ness */
     cctx->scx_line = next_ln;
 
     if ((int)strlen(pzEnd) >= schemeLen) {
@@ -437,7 +435,7 @@ static void
 alist_to_autogen_def(void)
 {
     char*  pzText  = ++(cctx->scx_scan);
-    char*  pzEnd   = (char*)skip_scheme(pzText, pzText + strlen(pzText));
+    char*  pzEnd   = (char *)skip_scheme(pzText, pzText + strlen(pzText));
 
     SCM    res;
     size_t res_len;
@@ -484,9 +482,9 @@ alist_to_autogen_def(void)
      */
     AGDUPSTR(pCtx->scx_fname, ALIST_TO_AG_TEXT, "scheme text");
     pCtx->scx_scan = \
-    pCtx->scx_data = (char*)(pCtx+1);
+    pCtx->scx_data = (char *)(pCtx + 1);
     pCtx->scx_line = 0;
-    memcpy((void*)(pCtx->scx_scan), (void*)AG_SCM_CHARS(res), res_len);
+    memcpy((void *)(pCtx->scx_scan), (void *)AG_SCM_CHARS(res), res_len);
     pCtx->scx_scan[ res_len ] = NUL;
 
     /*
@@ -602,7 +600,7 @@ build_here_str(char* scan)
      */
     {
         char * pz = SPN_VARIABLE_NAME_CHARS(scan);
-        markLen = pz - scan;
+        markLen = (size_t)(pz - scan);
 
         if (markLen == 0)
             AG_ABEND(aprf(DEF_ERR_FMT, ag_pname, HERE_MISS_MARK_STR,
