@@ -2,8 +2,6 @@
 /**
  * @file expGuile.c
  *
- *  Time-stamp:        "2012-01-29 07:06:37 bkorb"
- *
  *  This module implements the expression functions that should
  *  be part of Guile.
  *
@@ -48,7 +46,7 @@ ag_scm_c_eval_string_from_file_line(
     SCM port = scm_open_input_string(AG_SCM_STR02SCM(pzExpr));
 
     if (OPT_VALUE_TRACE >= TRACE_EVERYTHING)
-        fprintf(pfTrace, TRACE_EVAL_STRING, pzFile, line, pzExpr);
+        fprintf(trace_fp, TRACE_EVAL_STRING, pzFile, line, pzExpr);
 
     {
         static SCM    file      = SCM_UNDEFINED;
@@ -265,9 +263,7 @@ ag_scm_string_to_c_name_x(SCM str)
     if (! AG_SCM_STRING_P(str))
         scm_wrong_type_arg(STR_TO_C_NAME, 1, str);
 
-    
-    
-    for (pz = (char*)(void*)AG_SCM_CHARS(str), len = AG_SCM_STRLEN(str);
+    for (pz = C(char *, AG_SCM_CHARS(str)), len = AG_SCM_STRLEN(str);
          --len >= 0;
          pz++) {
 
@@ -304,7 +300,7 @@ ag_scm_string_upcase_x(SCM str)
         return SCM_UNDEFINED;
 
     len = AG_SCM_STRLEN(str);
-    pz  = (char*)(void*)AG_SCM_CHARS(str);
+    pz  = C(char *, AG_SCM_CHARS(str));
     while (--len >= 0) {
          char ch = *pz;
         if (IS_LOWER_CASE_CHAR(ch))
@@ -353,22 +349,22 @@ ag_scm_string_capitalize_x(SCM str)
 {
     int     len;
     char*   pz;
-    ag_bool word_start = AG_TRUE;
+    bool word_start = true;
 
     if (! AG_SCM_STRING_P(str))
         return SCM_UNDEFINED;
 
     len = AG_SCM_STRLEN(str);
-    pz  = (char*)(void*)AG_SCM_CHARS(str);
+    pz  = C(char *, AG_SCM_CHARS(str));
 
     while (--len >= 0) {
         char ch = *pz;
 
         if (! IS_ALPHANUMERIC_CHAR(ch)) {
-            word_start = AG_TRUE;
+            word_start = true;
 
         } else if (word_start) {
-            word_start = AG_FALSE;
+            word_start = false;
             if (IS_LOWER_CASE_CHAR(ch))
                 *pz = toupper(ch);
 
@@ -425,7 +421,7 @@ ag_scm_string_downcase_x(SCM str)
         return SCM_UNDEFINED;
 
     len = AG_SCM_STRLEN(str);
-    pz  = (char*)(void*)AG_SCM_CHARS(str);
+    pz  = C(char *, AG_SCM_CHARS(str));
     while (--len >= 0) {
         char ch = *pz;
         if (IS_UPPER_CASE_CHAR(ch))
@@ -477,34 +473,34 @@ ag_scm_string_to_camelcase(SCM str)
     int   len;
     char* pzd, * res;
     char* pzs;
-    ag_bool cap_done = AG_FALSE;
+    bool cap_done = false;
 
     if (! AG_SCM_STRING_P(str))
         return SCM_UNDEFINED;
 
     len = AG_SCM_STRLEN(str);
     res = pzd = ag_scribble(len + 1);
-    pzs = (char*)(void*)AG_SCM_CHARS(str);
+    pzs = C(char *, AG_SCM_CHARS(str));
 
     while (--len >= 0) {
         unsigned int ch = *(pzs++);
         if (IS_LOWER_CASE_CHAR(ch)) {
             if (! cap_done) {
                 ch = toupper(ch);
-                cap_done = AG_TRUE;
+                cap_done = true;
             }
 
         } else if (IS_UPPER_CASE_CHAR(ch)) {
             if (cap_done)
                 ch = tolower(ch);
             else
-                cap_done = AG_TRUE;
+                cap_done = true;
 
         } else if (IS_DEC_DIGIT_CHAR(ch)) {
-            cap_done = AG_FALSE;
+            cap_done = false;
 
         } else {
-            cap_done = AG_FALSE;
+            cap_done = false;
             continue;
         }
 
