@@ -2,13 +2,11 @@
 /**
  * @file expString.c
  *
- *  Time-stamp:        "2011-12-21 10:56:11 bkorb"
- *
  *  This module implements expression functions that
  *  manipulate string values.
  *
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -32,10 +30,10 @@ static SCM
 makeString(char const * pzText, char const * pzNewLine, size_t newLineSize);
 
 static size_t
-stringify_for_sh(char * pzNew, u_int qt, char const * pzDta, size_t dtaSize);
+stringify_for_sh(char * pzNew, uint_t qt, char const * pzDta);
 
 static SCM
-shell_stringify(SCM obj, u_int qt);
+shell_stringify(SCM obj, uint_t qt);
 
 static int
 sub_count(char const * haystack, char const * needle);
@@ -56,7 +54,7 @@ string_size(char const * pzScn, size_t newLineSize)
     /*
      *  Start by counting the start and end quotes, plus the NUL.
      */
-    size_t dtaSize = sizeof("\"\"");
+    size_t dtaSize = 3;
 
     for (;;) {
         char ch = *(pzScn++);
@@ -188,16 +186,13 @@ makeString(char const * pzText, char const * pzNewLine, size_t newLineSize)
             break;
 
         default:
-        {
-            static char const zFmt[] = "\\%03o";
             /*
              *  sprintf is safe here, because we already computed
              *  the amount of space we will be using.
              */
-            sprintf(pzDta, zFmt, ch);
+            sprintf(pzDta, MK_STR_OCT_FMT, ch);
             pzDta += 4;
         }
-        }
 
         pzScn++;
     } copyDone:
@@ -219,7 +214,7 @@ makeString(char const * pzText, char const * pzNewLine, size_t newLineSize)
 }
 
 static size_t
-stringify_for_sh(char * pzNew, u_int qt, char const * pzDta, size_t dtaSize)
+stringify_for_sh(char * pzNew, uint_t qt, char const * pzDta)
 {
     char * pz = pzNew;
     *(pz++) = qt;
@@ -230,7 +225,6 @@ stringify_for_sh(char * pzNew, u_int qt, char const * pzDta, size_t dtaSize)
         case NUL:
             pz[-1]  = qt;
             *pz     = NUL;
-            dtaSize = (pz - pzNew);
 
             return (pz - pzNew);
 
@@ -256,7 +250,7 @@ stringify_for_sh(char * pzNew, u_int qt, char const * pzDta, size_t dtaSize)
                  *  then we will double the backslash and a third backslash
                  *  will be inserted when we emit the quote character.
                  */
-                if (c != qt)
+                if ((unsigned)c != qt)
                     break;
                 /* FALLTHROUGH */
 
@@ -266,7 +260,7 @@ stringify_for_sh(char * pzNew, u_int qt, char const * pzDta, size_t dtaSize)
             break;
 
         case '"': case '`':
-            if (c == qt) {
+            if ((unsigned)c == qt) {
                 /*
                  *  This routine does both `xx` and "xx" strings, we have
                  *  to worry about this stuff differently.  I.e., in ""
@@ -281,7 +275,7 @@ stringify_for_sh(char * pzNew, u_int qt, char const * pzDta, size_t dtaSize)
 }
 
 static SCM
-shell_stringify(SCM obj, u_int qt)
+shell_stringify(SCM obj, uint_t qt)
 {
     char*  pzNew;
     size_t dtaSize = 3;
@@ -305,7 +299,7 @@ shell_stringify(SCM obj, u_int qt)
     } loopDone1:;
 
     pzNew = AGALOC(dtaSize, "shell string");
-    dtaSize = stringify_for_sh(pzNew, qt, pzDta, dtaSize);
+    dtaSize = stringify_for_sh(pzNew, qt, pzDta);
 
     {
         SCM res = AG_SCM_STR2SCM(pzNew, dtaSize);
@@ -638,9 +632,9 @@ ag_scm_prefix(SCM prefix, SCM text)
     size_t   pfx_size;
     char*    pzRes;
 
-    pzPfx   = ag_scm2zchars(prefix, "prefix");
-    pzDta   = \
-    pzText  = ag_scm2zchars(text, "text");
+    pzPfx    = ag_scm2zchars(prefix, "prefix");
+    pzDta    = \
+    pzText   = ag_scm2zchars(text, "text");
     pfx_size = strlen(pzPfx);
     out_size = pfx_size;
 
@@ -668,7 +662,7 @@ ag_scm_prefix(SCM prefix, SCM text)
         switch (ch) {
         case NUL:
             if (rem_size != 0)
-                AG_ABEND("(prefix ...) failed");
+                AG_ABEND(PREFIX_FAIL);
 
             return AG_SCM_STR2SCM(pzRes, out_size);
 
@@ -887,13 +881,13 @@ ag_scm_stack(SCM obj)
 {
     SCM         res;
     SCM *       pos = &res;
-    tDefEntry** ppDE;
-    tDefEntry*  pDE;
+    def_ent_t** ppDE;
+    def_ent_t*  pDE;
     SCM         str;
 
     res = SCM_EOL;
 
-    ppDE = findEntryList(ag_scm2zchars(obj, "AG Object"));
+    ppDE = find_def_ent_list(ag_scm2zchars(obj, "AG Object"));
     if (ppDE == NULL)
         return SCM_EOL;
 
@@ -903,10 +897,10 @@ ag_scm_stack(SCM obj)
         if (pDE == NULL)
             break;
 
-        if (pDE->valType != VALTYP_TEXT)
+        if (pDE->de_type != VALTYP_TEXT)
             return SCM_UNDEFINED;
 
-        str  = AG_SCM_STR02SCM(pDE->val.pzText);
+        str  = AG_SCM_STR02SCM(pDE->de_val.dvu_text);
         *pos = scm_cons(str, SCM_EOL);
         pos  = SCM_CDRLOC(*pos);
     }
@@ -932,10 +926,8 @@ ag_scm_stack(SCM obj)
 SCM
 ag_scm_kr_string(SCM str)
 {
-    static char const zNewLine[] = "\\n\\\n";
-
-    return makeString(ag_scm2zchars(str, "string"),
-                      zNewLine, sizeof(zNewLine)-1);
+    return makeString(ag_scm2zchars(str, "str"),
+                      KR_STRING_NEWLINE, KR_STRING_NEWLINE_LEN);
 }
 
 
@@ -961,10 +953,8 @@ ag_scm_kr_string(SCM str)
 SCM
 ag_scm_c_string(SCM str)
 {
-    static char const zNewLine[] = "\\n\"\n       \"";
-
-    return makeString(ag_scm2zchars(str, "string"),
-                      zNewLine, sizeof(zNewLine)-1);
+    return makeString(ag_scm2zchars(str, "str"),
+                      C_STRING_NEWLINE, C_STRING_NEWLINE_LEN);
 }
 
 
@@ -990,14 +980,14 @@ ag_scm_string_tr_x(SCM str, SCM from_xform, SCM to_xform)
 {
     unsigned char ch_map[ 1 << 8 /* bits-per-byte */ ];
     int   i      = sizeof(ch_map) - 1;
-    char* pzFrom = ag_scm2zchars(from_xform, "string");
-    char* pzTo   = ag_scm2zchars(to_xform, "string");
+    char* pzFrom = ag_scm2zchars(from_xform, "str");
+    char* pzTo   = ag_scm2zchars(to_xform, "str");
 
     do  {
         ch_map[i] = i;
     } while (--i > 0);
 
-    for (;i <= sizeof(ch_map) - 1;i++) {
+    for (; i <= (int)sizeof(ch_map) - 1; i++) {
         unsigned char fch = (unsigned char)*(pzFrom++);
         unsigned char tch = (unsigned char)*(pzTo++);
 
@@ -1030,7 +1020,7 @@ ag_scm_string_tr_x(SCM str, SCM from_xform, SCM to_xform)
         }
     } mapDone:;
 
-    pzTo = (char*)(void*)AG_SCM_CHARS(str);
+    pzTo = C(char *, AG_SCM_CHARS(str));
     i    = AG_SCM_STRLEN(str);
     while (i-- > 0) {
         *pzTo = ch_map[ (int)*pzTo ];
@@ -1127,7 +1117,7 @@ ag_scm_time_string_to_number(SCM time_spec)
 
     pz = AG_SCM_CHARS(time_spec);
     time_period = parse_duration(pz);
-    
+
     return AG_SCM_INT2SCM((int)time_period);
 }
 
