@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Sun May  6 16:21:18 PDT 2012
+ * Generated Thu Dec 27 12:59:23 PST 2012
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -48,6 +48,9 @@ initialize(int arg_ct, char** arg_vec);
 LOCAL void
 config_dep(tOptions * opts, tOptDesc * od);
 
+LOCAL void
+prep_env(void);
+
 /*
  *  Extracted from agShell.c
  */
@@ -228,10 +231,10 @@ mLoad_Leave(templ_t * tpl, macro_t * mac, char const ** p_scan);
  *  Extracted from loadPseudo.c
  */
 LOCAL char const *
-do_suffix(char const * const pzData, char const * pzFileName, int lineNo);
+do_suffix(char const * const text, char const * fname, int lineNo);
 
 LOCAL char const *
-loadPseudoMacro(char const * pzData, char const * pzFileName);
+loadPseudoMacro(char const * text, char const * fname);
 
 /*
  *  Extracted from scmStrings.c
@@ -258,10 +261,10 @@ LOCAL templ_t *
 find_tpl(char const * pzTemplName);
 
 LOCAL tSuccess
-find_file(char const * pzFName,
-          char * pzFullName,
-          char const * const * papSuffixList,
-          char const * pzReferrer);
+find_file(char const * in_name,
+          char *       res_name,
+          char const * const * sfx_list,
+          char const * referring_tpl);
 
 LOCAL templ_t *
 tpl_load(char const * fname, char const * referrer);
