@@ -1,6 +1,4 @@
 
-;;; Time-stamp:        "2012-04-14 08:39:41 bkorb"
-;;;
 ;;; This file is part of AutoGen.
 ;;; AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
 ;;;
@@ -105,6 +103,10 @@
 (define-macro (defined-as predicate symbol)
   `(and (defined? ',symbol) (,predicate ,symbol)))
 
+(catch #t
+  (lambda () (read-enable 'curly-infix))
+  (lambda args #f))
+
 ;;; /*=gfunc   html_escape_encode
 ;;;  *
 ;;;  * what:   encode html special characters
@@ -128,6 +130,19 @@
 (define stt-idx-tbl stt-table)
 (define stt-idx     0)
 
+;;; /*=gfunc   insert_suspended
+;;;  *
+;;;  * what:   insert a named suspension in current output
+;;;  *
+;;;  * exparg: susp-name , the name of the suspended output
+;;;  *
+;;;  * doc:    Emit into the current output the output suspended under a
+;;;  *         given diversion name.
+;;; =*/
+;;;
+(define insert-suspended (lambda (susp-name) (begin
+   (out-resume susp-name) (out-pop #t) )))
+
 ;;; /*=gfunc   string_table_new
 ;;;  *
 ;;;  * what:   create a string table
@@ -385,4 +400,5 @@
 (define stack-join (lambda (j-str ag-name)
   (join j-str (stack ag-name))))
 
+(version)
 ;;; end of agen5/schemedef.scm
