@@ -1,7 +1,5 @@
 #! /bin/sh
 
-# Time-stamp:        "2012-05-12 20:04:54 bkorb"
-#
 ##  This file is part of AutoOpts, a companion to AutoGen.
 ##  AutoOpts is free software.
 ##  AutoOpts is Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
@@ -28,12 +26,13 @@ egrep '#undef +AUTOOPTS_ENABLED' ${top_builddir}/config.h >/dev/null && \
 srcdir=`dirname $0`
 srcdir=`cd ${srcdir} ; pwd`
 
-. ${top_builddir}/autoopts/test/devs
+. ${top_builddir}/autoopts/test/defs
 
 test -z "${POSIX_SHELL}" && exit 1
 
-rm -f ${DESTdestdir}/options.h
+rm -f ${DESTdestdir}/options.h ${DESTdestdir}/usage-txt.h
 opthdrsrc=${srcdir}/autoopts/options.h
+usehdrsrc=${srcdir}/autoopts/usage-txt.h
 cfgf=${top_builddir}/config.h
 
 {
@@ -45,9 +44,9 @@ cfgf=${top_builddir}/config.h
 
     if ${EGREP} 'define +HAVE_LIMITS_H' ${cfgf} >/dev/null
     then echo '#include <limits.h>'
-    else echo '#include <sys/limits>' ; fi
+    else echo '#include <sys/limits.h>' ; fi
 
-    if ${EGREP} 'define +HAVE_STDBOOL_H' ${cfgf}
+    if ${EGREP} 'define +HAVE_STDBOOL_H' ${cfgf} >/dev/null
     then echo '#include <stdbool.h>'
     else cat <<- _EOF_
 	typedef enum { false = 0, true = 1 } _Bool;
@@ -89,6 +88,9 @@ cfgf=${top_builddir}/config.h
     sed "${sedcmd};${nopathfind}" ${opthdrsrc}
 } > ${DESTdestdir}/options.h
 
+sed '/#if.*AUTOOPTS_INTERNAL/,/#endif.*XGETTEXT_SCAN/d' \
+  ${usehdrsrc} > ${DESTdestdir}/usage-txt.h
+
 test -d "${DESTpkgdatadir}" && {
     rmbuild='/# *START-BUILDTREE-ISMS/,/# *END-BUILDTREE-ISMS/d
 	/# *END-INSTALL-ONLY-CODE/d
