@@ -2,8 +2,6 @@
 
 ## texi2man.sh -- script to convert texi-isms to man page isms
 ##
-## Time-stamp:      "2012-05-05 08:13:04 bkorb"
-##
 ##  This file is part of AutoOpts, a companion to AutoGen.
 ##  AutoOpts is free software.
 ##  AutoOpts is Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
@@ -45,7 +43,7 @@ do
     sedcmd="${sedcmd}s;@${f}${bracket};${replB};g${nl}"
 done
 
-for f in i file emph kbd key abbr acronym email
+for f in i file emph kbd key abbr acronym email indicateurl
 do
     sedcmd="${sedcmd}s;@${f}${bracket};${replI};g${nl}"
 done
