@@ -3,7 +3,6 @@
  *
  *  getdefs Copyright (c) 1999-2012 by Bruce Korb - all rights reserved
  *
- *  Time-stamp:        "2011-01-31 13:06:12 bkorb"
  *  Author:            Bruce Korb <bkorb@gnu.org>
  *
  *  This file is part of AutoGen.
@@ -76,13 +75,17 @@ static FILE*
 startAutogen(void);
 
 static void
-updateDatabase(void);
+update_db(void);
 /* END-STATIC-FORWARD */
 
 #ifndef HAVE_STRSIGNAL
 #  include "compat/strsignal.c"
 #endif
 
+#ifndef HAVE_CHMOD
+#  include "compat/chmod.c"
+#endif
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *   MAIN
@@ -124,6 +127,9 @@ main(int argc, char ** argv)
         qsort((void*)papzBlocks, blkUseCt, sizeof(char*), &compar_text);
 
     printEntries(outFp);
+#ifdef HAVE_FCHMOD
+    fchmod(fileno(outFp), S_IRUSR|S_IRGRP|S_IROTH);
+#endif
     fclose(outFp);
 
     /*
@@ -136,7 +142,9 @@ main(int argc, char ** argv)
         tbuf.actime  = time((time_t*)NULL);
         tbuf.modtime = modtime + 1;
         utime(OPT_ARG(OUTPUT), &tbuf);
+#ifndef HAVE_CHMOD
         chmod(OPT_ARG(OUTPUT), S_IRUSR|S_IRGRP|S_IROTH);
+#endif
     }
 
     /*
@@ -145,7 +153,7 @@ main(int argc, char ** argv)
      *  THEN append the new entries to the file.
      */
     if ((pzIndexText != NULL) && (pzEndIndex != pzIndexEOF))
-        updateDatabase();
+        update_db();
 
     if (agPid != -1)
         return awaitAutogen();
@@ -245,7 +253,7 @@ assignIndex(char*  pzOut,  char*  pzDef)
         *pz = ' ';
         pzMatch = strchr(pzMatch + len, '[');
         idx = strtol(pzMatch+1, (char**)NULL, 0)+1;
-    } while (0);
+    } while (false);
 
     /*
      *  Add the new entry to our text database and
@@ -297,14 +305,14 @@ buildDefinition(char * pzDef, char const * pzFile, int line, char * pzOut)
     static char const zSrcFile[] = "    %s = '%s';\n";
     static char const zLineNum[] = "    %s = '%d';\n";
 
-    ag_bool    these_are_global_defs;
+    bool    these_are_global_defs;
     tSuccess   preamble;
     int        re_res;
     char*      pzNextDef = NULL;
     regmatch_t match[2];
 
     if (*pzDef == '*') {
-        these_are_global_defs = AG_TRUE;
+        these_are_global_defs = true;
         strcpy(pzOut, zGlobal);
         pzOut += sizeof(zGlobal)-1;
         pzOut += sprintf(pzOut, zLineId, line, pzFile);
@@ -313,7 +321,7 @@ buildDefinition(char * pzDef, char const * pzFile, int line, char * pzOut)
         preamble = PROBLEM;
 
     } else {
-        these_are_global_defs = AG_FALSE;
+        these_are_global_defs = false;
         preamble = buildPreamble(&pzDef, &pzOut, pzFile, line);
         if (FAILED(preamble)) {
             *pzOut = NUL;
@@ -1149,10 +1157,10 @@ startAutogen(void)
 
 
 /*
- *  updateDatabase
+ *  update_db
  */
 static void
-updateDatabase(void)
+update_db(void)
 {
     FILE* fp;
 
@@ -1169,8 +1177,13 @@ updateDatabase(void)
         fserr_die("opening %s for write/append\n", OPT_ARG(ORDERING));
 
     fwrite(pzIndexEOF, (size_t)(pzEndIndex - pzIndexEOF), (size_t)1, fp);
+#ifdef HAVE_FCHMOD
+    fchmod(fileno(fp), 0444);
+    fclose(fp);
+#else
     fclose(fp);
     chmod(OPT_ARG(ORDERING), 0444);
+#endif
 }
 
 /* emacs
